@@ -8,6 +8,7 @@ from eth_typing import ChecksumAddress, HexAddress
 from eth_utils import encode_hex, is_address, to_checksum_address
 from eth_utils.units import units
 from hexbytes import HexBytes
+from solcx import link_code
 from web3 import Web3
 from web3.contract import Contract, ContractFunction
 from web3.middleware import construct_sign_and_send_raw_middleware
@@ -21,6 +22,8 @@ from raiden_contracts.constants import (
     CONTRACT_TOKEN_NETWORK_REGISTRY,
     CONTRACT_USER_DEPOSIT,
     CONTRACTS_VERSION,
+    LIBRARY_TOKEN_NETWORK_UTILS,
+    LIBRARY_TOKEN_NETWORK_UTILS_LINK_KEY,
     DeploymentModule,
 )
 from raiden_contracts.contract_manager import (
@@ -34,7 +37,7 @@ from raiden_contracts.deploy.contract_verifier import ContractVerifier
 from raiden_contracts.utils.file_ops import load_json_from_path
 from raiden_contracts.utils.signature import private_key_to_address
 from raiden_contracts.utils.transaction import check_successful_tx
-from raiden_contracts.utils.type_aliases import ChainID
+from raiden_contracts.utils.type_aliases import ChainID, PrivateKey
 from raiden_contracts.utils.versions import (
     contracts_version_monitoring_service_takes_token_network_registry,
 )
@@ -46,7 +49,7 @@ class ContractDeployer(ContractVerifier):
     def __init__(
         self,
         web3: Web3,
-        private_key: str,
+        private_key: PrivateKey,
         gas_limit: int,
         gas_price: int,
         wait: int = 10,
@@ -76,15 +79,31 @@ class ContractDeployer(ContractVerifier):
         else:
             LOG.info("Skipped checks against the source code because it is not available.")
 
-    def deploy(self, contract_name: str, args: Optional[List] = None) -> TxReceipt:
+    def deploy(
+        self, contract_name: str, libs: Dict = None, args: Optional[List] = None
+    ) -> TxReceipt:
         if args is None:
             args = list()
         contract_interface: CompiledContract = self.contract_manager.get_contract(contract_name)
 
+        abi = contract_interface["abi"]
+        bytecode = contract_interface["bin"]
+        bytecode_runtime = None
+
+        if isinstance(libs, dict) and len(libs.keys()) > 0:
+            bytecode = link_code(bytecode, libs)
+            bytecode_runtime = link_code(contract_interface["bin-runtime"], libs)
+
         # Instantiate and deploy contract
-        contract = self.web3.eth.contract(
-            abi=contract_interface["abi"], bytecode=contract_interface["bin"]
-        )
+        if bytecode_runtime:
+            contract = self.web3.eth.contract(
+                abi=abi, bytecode=bytecode, bytecode_runtime=bytecode_runtime
+            )
+        else:
+            contract = self.web3.eth.contract(
+                abi=abi,
+                bytecode=bytecode,
+            )
 
         # Get transaction hash from deployed contract
         txhash = self.send_deployment_transaction(contract=contract, args=args)
@@ -149,7 +168,7 @@ class ContractDeployer(ContractVerifier):
         settle_timeout_min: int,
         settle_timeout_max: int,
     ) -> DeployedContracts:
-        """ Deploy all required raiden contracts and return a dict of contract_name:address
+        """Deploy all required raiden contracts and return a dict of contract_name:address
 
         Args:
             max_num_of_token_networks (Optional[int]): The max number of tokens that can be
@@ -159,7 +178,7 @@ class ContractDeployer(ContractVerifier):
 
         deployed_contracts: DeployedContracts = {
             "contracts_version": self.contract_manager.contracts_version,
-            "chain_id": self.web3.eth.chainId,
+            "chain_id": self.web3.eth.chain_id,
             "contracts": {},
         }
 
@@ -186,26 +205,52 @@ class ContractDeployer(ContractVerifier):
                 arguments=[],
                 deployed_contracts=deployed_contracts,
             )
-        token_network_registry_args = [
-            secret_registry.address,
-            deployed_contracts["chain_id"],
-            settle_timeout_min,
-            settle_timeout_max,
-            max_num_of_token_networks,
-        ]
-        self._deploy_and_remember(
-            contract_name=CONTRACT_TOKEN_NETWORK_REGISTRY,
-            arguments=token_network_registry_args,
-            deployed_contracts=deployed_contracts,
-        )
+
+        if self.contracts_version != "0.37.0":
+            token_network_libs = self._deploy_and_remember(
+                contract_name=LIBRARY_TOKEN_NETWORK_UTILS,
+                arguments=[],
+                deployed_contracts=deployed_contracts,
+            )
+
+            token_network_registry_args = [
+                secret_registry.address,
+                deployed_contracts["chain_id"],
+                settle_timeout_min,
+                settle_timeout_max,
+                max_num_of_token_networks,
+            ]
+            self._deploy_and_remember(
+                contract_name=CONTRACT_TOKEN_NETWORK_REGISTRY,
+                arguments=token_network_registry_args,
+                deployed_contracts=deployed_contracts,
+                libs={LIBRARY_TOKEN_NETWORK_UTILS_LINK_KEY: token_network_libs.address},
+            )
+        else:
+            token_network_registry_args = [
+                secret_registry.address,
+                deployed_contracts["chain_id"],
+                settle_timeout_min,
+                settle_timeout_max,
+                max_num_of_token_networks,
+            ]
+            self._deploy_and_remember(
+                contract_name=CONTRACT_TOKEN_NETWORK_REGISTRY,
+                arguments=token_network_registry_args,
+                deployed_contracts=deployed_contracts,
+            )
 
         return deployed_contracts
 
     def _deploy_and_remember(
-        self, contract_name: str, arguments: List, deployed_contracts: DeployedContracts
+        self,
+        contract_name: str,
+        arguments: List,
+        deployed_contracts: DeployedContracts,
+        libs: Dict = None,
     ) -> Contract:
         """ Deploys contract_name with arguments and store the result in deployed_contracts. """
-        receipt = self.deploy(contract_name, arguments)
+        receipt = self.deploy(contract_name, libs, arguments)
         deployed_contracts["contracts"][contract_name] = _deployed_data_from_receipt(
             receipt=receipt, constructor_arguments=arguments
         )
@@ -233,7 +278,7 @@ class ContractDeployer(ContractVerifier):
         self.transact(command)
 
         LOG.debug("Collecting constructor parameters for later verification")
-        chain_id = ChainID(self.web3.eth.chainId)
+        chain_id = ChainID(self.web3.eth.chain_id)
         deployment_data = get_contracts_deployment_info(
             chain_id=chain_id,
             version=self.contract_manager.contracts_version,
@@ -284,6 +329,7 @@ class ContractDeployer(ContractVerifier):
         min_price: int,
         registration_duration: int,
         token_network_registry_address: HexAddress,
+        reuse_service_registry_from_deploy_file: Optional[Path],
     ) -> DeployedContracts:
         """Deploy 3rd party service contracts"""
         if not contracts_version_monitoring_service_takes_token_network_registry(
@@ -291,27 +337,46 @@ class ContractDeployer(ContractVerifier):
         ):
             raise RuntimeError("Deployment of older service contracts is not suppported.")
 
-        chain_id = self.web3.eth.chainId
+        chain_id = self.web3.eth.chain_id
         deployed_contracts: DeployedContracts = {
             "contracts_version": self.contract_manager.contracts_version,
             "chain_id": chain_id,
             "contracts": {},
         }
 
-        service_registry = self._deploy_and_remember(
-            CONTRACT_SERVICE_REGISTRY,
-            [
-                token_address,
-                service_registry_controller,
-                initial_service_deposit_price,
-                service_deposit_bump_numerator,
-                service_deposit_bump_denominator,
-                decay_constant,
-                min_price,
-                registration_duration,
-            ],
-            deployed_contracts,
-        )
+        if reuse_service_registry_from_deploy_file:
+            reused_doc = DeployedContracts(  # type: ignore
+                load_json_from_path(reuse_service_registry_from_deploy_file)
+            )
+            if not reused_doc:
+                raise RuntimeError(
+                    f"{reuse_service_registry_from_deploy_file} does not contain deployment data."
+                )
+            reused_contracts = reused_doc["contracts"]
+
+            service_registry = self.contract_instance_from_deployment_data(
+                reused_doc, CONTRACT_SERVICE_REGISTRY
+            )
+
+            deployed_contracts["contracts"][CONTRACT_SERVICE_REGISTRY] = deepcopy(
+                reused_contracts[CONTRACT_SERVICE_REGISTRY]
+            )
+        else:
+            service_registry = self._deploy_and_remember(
+                contract_name=CONTRACT_SERVICE_REGISTRY,
+                arguments=[
+                    token_address,
+                    service_registry_controller,
+                    initial_service_deposit_price,
+                    service_deposit_bump_numerator,
+                    service_deposit_bump_denominator,
+                    decay_constant,
+                    min_price,
+                    registration_duration,
+                ],
+                deployed_contracts=deployed_contracts,
+            )
+
         user_deposit = self._deploy_and_remember(
             contract_name=CONTRACT_USER_DEPOSIT,
             arguments=[token_address, user_deposit_whole_balance_limit],
