@@ -84,7 +84,11 @@ def test_update_call(
     # Failure with the zero signature
     with pytest.raises(TransactionFailed):
         token_network.functions.updateNonClosingBalanceProof(
-            channel_identifier, A, B, *balance_proof_A._asdict().values(), EMPTY_SIGNATURE
+            channel_identifier,
+            A,
+            B,
+            *balance_proof_A._asdict().values(),
+            EMPTY_SIGNATURE,
         ).call({"from": C})
 
     # Failure with the empty balance hash
@@ -300,7 +304,13 @@ def test_update_wrong_nonce_fail(
         ).call({"from": A})
 
     update_state_tests(
-        channel_identifier, A, balance_proof_A, B, balance_proof_B, settle_timeout, txn_hash1
+        channel_identifier,
+        A,
+        balance_proof_A,
+        B,
+        balance_proof_B,
+        settle_timeout,
+        txn_hash1,
     )
 
 
@@ -422,10 +432,10 @@ def test_update_channel_state(
         {"from": A},
     )
 
-    pre_eth_balance_A = web3.eth.getBalance(A)
-    pre_eth_balance_B = web3.eth.getBalance(B)
-    pre_eth_balance_delegate = web3.eth.getBalance(Delegate)
-    pre_eth_balance_contract = web3.eth.getBalance(token_network.address)
+    pre_eth_balance_A = web3.eth.get_balance(A)
+    pre_eth_balance_B = web3.eth.get_balance(B)
+    pre_eth_balance_delegate = web3.eth.get_balance(Delegate)
+    pre_eth_balance_contract = web3.eth.get_balance(token_network.address)
     pre_balance_A = custom_token.functions.balanceOf(A).call()
     pre_balance_B = custom_token.functions.balanceOf(B).call()
     pre_balance_delegate = custom_token.functions.balanceOf(Delegate).call()
@@ -444,17 +454,23 @@ def test_update_channel_state(
 
     # Test that no balances have changed.
     # There are no transfers to be made in updateNonClosingBalanceProof.
-    assert web3.eth.getBalance(A) == pre_eth_balance_A
-    assert web3.eth.getBalance(B) == pre_eth_balance_B
-    assert web3.eth.getBalance(Delegate) == pre_eth_balance_delegate - txn_cost(txn_hash)
-    assert web3.eth.getBalance(token_network.address) == pre_eth_balance_contract
+    assert web3.eth.get_balance(A) == pre_eth_balance_A
+    assert web3.eth.get_balance(B) == pre_eth_balance_B
+    assert web3.eth.get_balance(Delegate) == pre_eth_balance_delegate - txn_cost(txn_hash)
+    assert web3.eth.get_balance(token_network.address) == pre_eth_balance_contract
     assert custom_token.functions.balanceOf(A).call() == pre_balance_A
     assert custom_token.functions.balanceOf(B).call() == pre_balance_B
     assert custom_token.functions.balanceOf(Delegate).call() == pre_balance_delegate
     assert custom_token.functions.balanceOf(token_network.address).call() == pre_balance_contract
 
     update_state_tests(
-        channel_identifier, A, balance_proof_A, B, balance_proof_B, settle_timeout, txn_hash1
+        channel_identifier,
+        A,
+        balance_proof_A,
+        B,
+        balance_proof_B,
+        settle_timeout,
+        txn_hash1,
     )
 
 
@@ -599,7 +615,11 @@ def test_update_not_allowed_for_the_closing_address(
     # A closes with the first balance proof
     call_and_transact(
         token_network.functions.closeChannel(
-            channel_identifier, B, A, *balance_proof_B_0._asdict().values(), closing_sig_A_0
+            channel_identifier,
+            B,
+            A,
+            *balance_proof_B_0._asdict().values(),
+            closing_sig_A_0,
         ),
         {"from": A},
     )
