@@ -146,6 +146,7 @@ def deployed_service_info(
         min_price=1000,
         registration_duration=180 * SECONDS_PER_DAY,
         token_network_registry_address=token_network_registry_contract.address,
+        reuse_service_registry_from_deploy_file=None,
     )
 
 
@@ -168,11 +169,13 @@ def test_deploy_service_0_37_0(
             min_price=1000,
             registration_duration=180 * SECONDS_PER_DAY,
             token_network_registry_address=token_network_registry_contract.address,
+            reuse_service_registry_from_deploy_file=None,
         )
 
 
 @pytest.mark.parametrize(
-    "version,expectation", [(ALDERAAN_VERSION, True), (None, True)],
+    "version,expectation",
+    [(ALDERAAN_VERSION, True), (None, True)],
 )
 def test_contracts_version_with_max_token_networks(
     version: Optional[str], expectation: bool
@@ -181,7 +184,8 @@ def test_contracts_version_with_max_token_networks(
 
 
 @pytest.mark.parametrize(
-    "version,expectation", [(ALDERAAN_VERSION, True), (None, True)],
+    "version,expectation",
+    [(ALDERAAN_VERSION, True), (None, True)],
 )
 def test_contracts_version_monitoring_service_takes_token_network_registry(
     version: Optional[str], expectation: bool
@@ -198,7 +202,7 @@ def test_deploy_script_raiden(
     deployed_raiden_info: DeployedContracts,
     deployed_raiden_info2: DeployedContracts,
 ) -> None:
-    """ Run raiden contracts deployment function and tamper with deployed_contracts_info
+    """Run raiden contracts deployment function and tamper with deployed_contracts_info
 
     This checks if deploy_raiden_contracts() works correctly in the happy case,
     to make sure no code dependencies have been changed, affecting the deployment script.
@@ -299,7 +303,11 @@ def test_deploy_script_raiden(
 
     # check that it fails if sender has no eth
     deployer = ContractDeployer(
-        web3=web3, private_key=get_random_privkey(), gas_limit=GAS_LIMIT, gas_price=1, wait=10
+        web3=web3,
+        private_key=get_random_privkey(),
+        gas_limit=GAS_LIMIT,
+        gas_price=1,
+        wait=10,
     )
     with pytest.raises(ValidationError):
         deployer.deploy_raiden_contracts(
@@ -333,8 +341,41 @@ def test_deploy_raiden_reuse_secret_registry(
         )
 
 
+def test_deploy_services_reuse_service_registry(
+    deployer: ContractDeployer,
+    deployed_service_info: DeployedContracts,
+    token_address: HexAddress,
+    token_network_registry_contract: Contract,
+) -> None:
+    """ Run deploy_service_contracts with a previous ServiceRegistry deployment data """
+    with NamedTemporaryFile() as previous_deployment_file:
+        previous_deployment_file.write(bytearray(json.dumps(deployed_service_info), "ascii"))
+        previous_deployment_file.flush()
+        new_deployment = deployer.deploy_service_contracts(
+            token_address=token_address,
+            user_deposit_whole_balance_limit=DEPOSIT_LIMIT,
+            service_registry_controller=DEPLOYER_ADDRESS,
+            initial_service_deposit_price=SERVICE_DEPOSIT // 2,
+            service_deposit_bump_numerator=6,
+            service_deposit_bump_denominator=5,
+            decay_constant=200 * SECONDS_PER_DAY,
+            min_price=1000,
+            registration_duration=180 * SECONDS_PER_DAY,
+            token_network_registry_address=token_network_registry_contract.address,
+            reuse_service_registry_from_deploy_file=Path(previous_deployment_file.name),
+        )
+        assert (
+            new_deployment["contracts"][CONTRACT_SERVICE_REGISTRY]
+            == deployed_service_info["contracts"][CONTRACT_SERVICE_REGISTRY]
+        )
+        assert (
+            new_deployment["contracts"][CONTRACT_ONE_TO_N]
+            != deployed_service_info["contracts"][CONTRACT_ONE_TO_N]
+        )
+
+
 def test_deploy_script_token(web3: Web3) -> None:
-    """ Run test token deployment function used in the deployment script
+    """Run test token deployment function used in the deployment script
 
     This checks if deploy_token_contract() works correctly in the happy case,
     to make sure no code dependencies have been changed, affecting the deployment script.
@@ -344,7 +385,11 @@ def test_deploy_script_token(web3: Web3) -> None:
     token_type = "CustomToken"
     gas_limit = 5860000
     deployer = ContractDeployer(
-        web3=web3, private_key=FAUCET_PRIVATE_KEY, gas_limit=gas_limit, gas_price=1, wait=10
+        web3=web3,
+        private_key=FAUCET_PRIVATE_KEY,
+        gas_limit=gas_limit,
+        gas_price=1,
+        wait=10,
     )
 
     deployed_token = deployer.deploy_token_contract(
@@ -360,7 +405,11 @@ def test_deploy_script_token(web3: Web3) -> None:
 
     # check that it fails if sender has no eth
     deployer = ContractDeployer(
-        web3=web3, private_key=get_random_privkey(), gas_limit=gas_limit, gas_price=1, wait=10
+        web3=web3,
+        private_key=get_random_privkey(),
+        gas_limit=gas_limit,
+        gas_price=1,
+        wait=10,
     )
     with pytest.raises(ValidationError):
         deployer.deploy_token_contract(
@@ -380,7 +429,7 @@ def test_deploy_script_register(
     deployed_raiden_info: DeployedContracts,
     token_address: ChecksumAddress,
 ) -> None:
-    """ Run token register function used in the deployment script
+    """Run token register function used in the deployment script
 
     This checks if register_token_network() works correctly in the happy case,
     to make sure no code dependencies have been changed, affecting the deployment script.
@@ -389,7 +438,11 @@ def test_deploy_script_register(
     # normal deployment
     gas_limit = 5860000
     deployer = ContractDeployer(
-        web3=web3, private_key=FAUCET_PRIVATE_KEY, gas_limit=gas_limit, gas_price=1, wait=10
+        web3=web3,
+        private_key=FAUCET_PRIVATE_KEY,
+        gas_limit=gas_limit,
+        gas_price=1,
+        wait=10,
     )
 
     token_registry_abi = deployer.contract_manager.get_contract_abi(
@@ -420,13 +473,17 @@ def test_deploy_script_service(
     token_address: HexAddress,
     token_network_registry_contract: Contract,
 ) -> None:
-    """ Run deploy_service_contracts() used in the deployment script
+    """Run deploy_service_contracts() used in the deployment script
 
     This checks if deploy_service_contracts() works correctly in the happy case.
     """
     gas_limit = 5860000
     deployer = ContractDeployer(
-        web3=web3, private_key=FAUCET_PRIVATE_KEY, gas_limit=gas_limit, gas_price=1, wait=10
+        web3=web3,
+        private_key=FAUCET_PRIVATE_KEY,
+        gas_limit=gas_limit,
+        gas_price=1,
+        wait=10,
     )
 
     token_supply = 10000000
@@ -668,7 +725,10 @@ def test_validate_address_happy_path() -> None:
 @pytest.fixture
 def fs_reload_deployer() -> Generator[FakeFilesystem, None, None]:
     patcher = Patcher(
-        modules_to_reload=[raiden_contracts.contract_manager, raiden_contracts.deploy.__main__]
+        modules_to_reload=[
+            raiden_contracts.contract_manager,
+            raiden_contracts.deploy.__main__,
+        ]
     )
     patcher.setUp()
     yield patcher.fs
@@ -790,7 +850,7 @@ def test_deploy_token_no_balance(privkey_file: IO) -> None:
     with patch.object(
         ContractDeployer, "deploy_token_contract", spec=ContractDeployer
     ) as mock_deployer:
-        with patch.object(Eth, "getBalance", return_value=0):
+        with patch.object(Eth, "get_balance", return_value=0):
             runner = CliRunner()
             result = runner.invoke(token, deploy_token_arguments(privkey=privkey_file.name))
             assert result.exit_code != 0
@@ -802,9 +862,12 @@ def test_deploy_token_no_balance(privkey_file: IO) -> None:
 def test_deploy_token_with_balance(privkey_file: IO) -> None:
     """ Call deploy token command with a private key with some balance """
     with patch.object(
-        ContractDeployer, "deploy_token_contract", spec=ContractDeployer, return_value={}
+        ContractDeployer,
+        "deploy_token_contract",
+        spec=ContractDeployer,
+        return_value={},
     ) as mock_deployer:
-        with patch.object(Eth, "getBalance", return_value=100):
+        with patch.object(Eth, "get_balance", return_value=100):
             runner = CliRunner()
             result = runner.invoke(token, deploy_token_arguments(privkey=privkey_file.name))
             assert result.exit_code == 0
@@ -848,7 +911,7 @@ def test_deploy_raiden(
     privkey_file: IO,
 ) -> None:
     """ Calling deploy raiden command """
-    with patch.object(Eth, "getBalance", return_value=1):
+    with patch.object(Eth, "get_balance", return_value=1):
         runner = CliRunner()
         result = runner.invoke(
             raiden,
@@ -867,7 +930,9 @@ def test_deploy_raiden(
 
 @patch.object(ContractDeployer, "register_token_network")
 def test_register_script(
-    mock_deploy: MagicMock, deployed_raiden_info: DeployedContracts, privkey_file: IO,
+    mock_deploy: MagicMock,
+    deployed_raiden_info: DeployedContracts,
+    privkey_file: IO,
 ) -> None:
     """ Calling deploy raiden command """
     with patch(
@@ -876,7 +941,7 @@ def test_register_script(
         "raiden_contracts.deploy.__main__._add_token_network_deploy_info"
     ) as add_tn_info:
         get_deploy_info_mock.return_value = deployed_raiden_info
-        with patch.object(Eth, "getBalance", return_value=1), patch.object(Eth, "chainId", 61):
+        with patch.object(Eth, "get_balance", return_value=1), patch.object(Eth, "chainId", 61):
             runner = CliRunner()
             result = runner.invoke(
                 register,
@@ -906,7 +971,7 @@ def test_register_script(
 @patch.object(ContractDeployer, "register_token_network")
 def test_register_script_without_token_network(mock_deploy: MagicMock, privkey_file: IO) -> None:
     """ Calling deploy raiden command """
-    with patch.object(Eth, "getBalance", return_value=1):
+    with patch.object(Eth, "get_balance", return_value=1):
         runner = CliRunner()
         result = runner.invoke(
             register,
@@ -940,7 +1005,7 @@ def test_deploy_raiden_save_info_false(
     mock_deploy: MagicMock, mock_verify: MagicMock, privkey_file: IO
 ) -> None:
     """ Calling deploy raiden command with --save_info False"""
-    with patch.object(Eth, "getBalance", return_value=1):
+    with patch.object(Eth, "get_balance", return_value=1):
         runner = CliRunner()
         result = runner.invoke(
             raiden,
@@ -1005,7 +1070,7 @@ def deploy_services_arguments(
 @patch.object(ContractVerifier, "store_and_verify_deployment_info_services")
 def test_deploy_services(mock_deploy: MagicMock, mock_verify: MagicMock, privkey_file: IO) -> None:
     """ Calling deploy raiden command """
-    with patch.object(Eth, "getBalance", return_value=1):
+    with patch.object(Eth, "get_balance", return_value=1):
         runner = CliRunner()
         result = runner.invoke(
             services,
@@ -1024,7 +1089,7 @@ def test_deploy_services(mock_deploy: MagicMock, mock_verify: MagicMock, privkey
 
 def test_deploy_old_services(privkey_file: IO) -> None:
     """ Calling deploy raiden command """
-    with patch.object(Eth, "getBalance", return_value=1):
+    with patch.object(Eth, "get_balance", return_value=1):
         runner = CliRunner()
         result = runner.invoke(
             services,
@@ -1046,7 +1111,7 @@ def test_deploy_services_with_controller(
     mock_deploy: MagicMock, mock_verify: MagicMock, privkey_file: IO
 ) -> None:
     """ Calling deploy raiden command """
-    with patch.object(Eth, "getBalance", return_value=1):
+    with patch.object(Eth, "get_balance", return_value=1):
         runner = CliRunner()
         result = runner.invoke(
             services,
@@ -1069,7 +1134,7 @@ def test_deploy_services_save_info_false(
     mock_deploy: MagicMock, mock_verify: MagicMock, privkey_file: IO
 ) -> None:
     """ Calling deploy raiden command with --save_info False"""
-    with patch.object(Eth, "getBalance", return_value=1):
+    with patch.object(Eth, "get_balance", return_value=1):
         runner = CliRunner()
         result = runner.invoke(
             services,
@@ -1089,7 +1154,7 @@ def test_deploy_services_save_info_false(
 @patch.object(ContractVerifier, "verify_deployed_contracts_in_filesystem")
 def test_verify_script(mock_verify: MagicMock) -> None:
     """ Calling deploy verify command """
-    with patch.object(Eth, "getBalance", return_value=1):
+    with patch.object(Eth, "get_balance", return_value=1):
         runner = CliRunner()
         result = runner.invoke(verify, ["--rpc-provider", "rpc-provider"])
         assert result.exception is None
