@@ -59,7 +59,7 @@ class LogHandler:
         self.wait(timeout)
 
     def _handle_waited_log(self, event: Dict[str, Any]) -> None:
-        """ A subroutine of handle_log
+        """A subroutine of handle_log
         Increment self.event_count, forget about waiting, and call the callback if any.
         """
         txn_hash = event["transactionHash"]
@@ -118,7 +118,7 @@ class LogHandler:
     def assert_event(
         self, txn_hash: str, event_name: str, args: List[Any], timeout: int = 5
     ) -> None:
-        """ Assert that `event_name` is emitted with the `args`
+        """Assert that `event_name` is emitted with the `args`
 
         For use in tests only.
         """
@@ -173,7 +173,7 @@ class LogFilter:
         )
         log_data_extract_fn = functools.partial(get_event_data, web3.codec, event_abi)
 
-        self.filter: Web3LogFilter = web3.eth.filter(filter_params)  # type: ignore
+        self.filter: Web3LogFilter = web3.eth.filter(filter_params)
         self.filter.set_data_filters(data_filter_set)  # type: ignore
         self.filter.log_entry_formatter = log_data_extract_fn
         self.filter.filter_params = filter_params
